import { TagManager } from "aws-cdk-lib";
import { Construct, IConstruct } from "constructs";
import { IParent } from "./parent";
import { PolicyType } from "./policy";
import { IPolicyAttachmentTarget } from "./policy-attachment";
import { ITaggableResource } from "./tag-resource";
/**
 * (experimental) Specifies the feature set supported by the new organization.
 *
 * Each feature set supports different levels of functionality.
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set
 * @experimental
 */
export declare enum FeatureSet {
    /**
     * (experimental) All member accounts have their bills consolidated to and paid by the management account.
     *
     * For more information, see [Consolidated billing](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-cb-only) in the AWS Organizations User Guide. The consolidated billing feature subset isn’t available for organizations in the AWS GovCloud (US) Region.
     *
     * @experimental
     */
    CONSOLIDATED_BILLING = "CONSOLIDATED_BILLING",
    /**
     * (experimental) In addition to all the features supported by the consolidated billing feature set, the management account can also apply any policy type to any member account in the organization.
     *
     * For more information, see [All features](https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html#feature-set-all) in the AWS Organizations User Guide.
     *
     * @experimental
     */
    ALL = "ALL"
}
/**
 * @experimental
 */
export interface OrganizationProps {
    /**
     * (experimental) Enabling features in your organization.
     *
     * @default ALL
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_support-all-features.html
     * @experimental
     */
    readonly featureSet?: FeatureSet;
}
/**
 * (experimental) Creates an organization to consolidate your AWS accounts so that you can administer them as a single unit.
 *
 * An organization has one management account along with zero or more member accounts. You can organize the accounts in a hierarchical, tree-like structure with a root at the top and organizational units nested under the root. Each account can be directly in the root, or placed in one of the OUs in the hierarchy. An organization has the functionality that is determined by the feature set that you enable.
 *
 * <strong>The account whose user is calling the CreateOrganization operation automatically becomes the management account of the new organization.</strong>
 *
 * <strong>For deletion of an organization you must previously remove all the member accounts, OUs, and policies from the organization!</strong>
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_org_create.html#create-org
 * @experimental
 */
export interface IOrganization extends IConstruct {
    /**
     * (experimental) The unique identifier (ID) of an organization.
     *
     * The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits.
     *
     * @experimental
     */
    readonly organizationId: string;
    /**
     * (experimental) The Amazon Resource Name (ARN) of an organization.
     *
     * @experimental
     */
    readonly organizationArn: string;
    /**
     * (experimental) Specifies the functionality that currently is available to the organization.
     *
     * If set to "ALL", then all features are enabled and policies can be applied to accounts in the organization. If set to "CONSOLIDATED_BILLING", then only consolidated billing functionality is available.
     *
     * @experimental
     */
    readonly featureSet: FeatureSet;
    /**
     * (experimental) The Amazon Resource Name (ARN) of the account that is designated as the management account for the organization.
     *
     * @experimental
     */
    readonly managementAccountArn: string;
    /**
     * (experimental) The unique identifier (ID) of the management account of an organization.
     *
     * @experimental
     */
    readonly managementAccountId: string;
    /**
     * (experimental) The email address that is associated with the AWS account that is designated as the management account for the organization.
     *
     * @experimental
     */
    readonly managementAccountEmail: string;
    /**
     * (experimental) The root of the current organization, which is automatically created.
     *
     * @experimental
     */
    readonly root: Root;
    /**
     * (experimental) Enables trusted access for a supported AWS service (trusted service), which performs tasks in your organization and its accounts on your behalf.
     *
     * @param servicePrincipal The supported AWS service that you specify.
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services_list.html
     * @experimental
     */
    enableAwsServiceAccess(servicePrincipal: string): void;
    /**
     * (experimental) Enables policy types in the following two broad categories: Authorization policies and Management policies.
     *
     * @param policyType : the type of the policy that you specify.
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies.html#orgs-policy-types
     * @experimental
     */
    enablePolicyType(policyType: PolicyType): void;
}
/**
 * @experimental
 */
export declare class Organization extends Construct implements IOrganization {
    /**
     * (experimental) The unique identifier (ID) of an organization.
     *
     * The regex pattern for an organization ID string requires "o-" followed by from 10 to 32 lowercase letters or digits.
     *
     * @experimental
     */
    readonly organizationId: string;
    /**
     * (experimental) The Amazon Resource Name (ARN) of an organization.
     *
     * @experimental
     */
    readonly organizationArn: string;
    /**
     * (experimental) Specifies the functionality that currently is available to the organization.
     *
     * If set to "ALL", then all features are enabled and policies can be applied to accounts in the organization. If set to "CONSOLIDATED_BILLING", then only consolidated billing functionality is available.
     *
     * @experimental
     */
    readonly featureSet: FeatureSet;
    /**
     * (experimental) The Amazon Resource Name (ARN) of the account that is designated as the management account for the organization.
     *
     * @experimental
     */
    readonly managementAccountArn: string;
    /**
     * (experimental) The unique identifier (ID) of the management account of an organization.
     *
     * @experimental
     */
    readonly managementAccountId: string;
    /**
     * (experimental) The email address that is associated with the AWS account that is designated as the management account for the organization.
     *
     * @experimental
     */
    readonly managementAccountEmail: string;
    /**
     * (experimental) The root of the current organization, which is automatically created.
     *
     * @experimental
     */
    readonly root: Root;
    private readonly resource;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: OrganizationProps);
    /**
     * (experimental) Enables trusted access for a supported AWS service (trusted service), which performs tasks in your organization and its accounts on your behalf.
     *
     * @param servicePrincipal The supported AWS service that you specify.
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_integrate_services_list.html
     * @experimental
     */
    enableAwsServiceAccess(servicePrincipal: string): void;
    /**
     * (experimental) Enables policy types in the following two broad categories: Authorization policies and Management policies.
     *
     * @param policyType : the type of the policy that you specify.
     * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies.html#orgs-policy-types
     * @experimental
     */
    enablePolicyType(policyType: PolicyType): void;
}
/**
 * (experimental) The parent container for all the accounts for your organization.
 *
 * If you apply a policy to the root, it applies to all organizational units (OUs) and accounts in the organization.
 * <strong>Currently, you can have only one root. AWS Organizations automatically creates it for you when you create an organization.</strong>
 *
 * @see https://docs.aws.amazon.com/organizations/latest/userguide/orgs_getting-started_concepts.html
 * @experimental
 */
export declare class Root extends Construct implements IParent, IPolicyAttachmentTarget, ITaggableResource {
    /**
     * (experimental) The unique identifier (ID) for the root.
     *
     * The regex pattern for a root ID string requires "r-" followed by from 4 to 32 lowercase letters or digits.
     *
     * @experimental
     */
    readonly rootId: string;
    /**
     * (experimental) TagManager to set, remove and format tags.
     *
     * @experimental
     */
    readonly tags: TagManager;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string);
    /**
     * (experimental) The unique identifier (ID) of the parent root, organizational unit (OU), account, or policy that you want to create the new OU in.
     *
     * @experimental
     */
    identifier(): string;
}
